predictivesearch/PcsAlgorithm/Algorithm1/inc/CPcsKeyMap.h
branchRCL_3
changeset 21 b3431bff8c19
parent 15 e8e3147d53eb
child 64 c1e8ba0c2b16
--- a/predictivesearch/PcsAlgorithm/Algorithm1/inc/CPcsKeyMap.h	Mon Mar 15 12:39:26 2010 +0200
+++ b/predictivesearch/PcsAlgorithm/Algorithm1/inc/CPcsKeyMap.h	Wed Mar 31 21:13:53 2010 +0300
@@ -73,6 +73,9 @@
          */
         virtual ~CPcsKeyMap();
 
+        TBool IsItutPredictiveAvailable() const;
+        TBool IsQwertyPredictiveAvailable() const;
+
         static TBool IsModePredictive( TKeyboardModes aKbMode );
 
         /**
@@ -125,9 +128,10 @@
         void ConstructL();
 
         /**
          * Select keyboard types according to available physical keyboard(s)
          */
-        void SetupKeyboardTypesL();
+        void GetPhysicalKeyboardTypesL( TPtiKeyboardType& aItutKbType,
+                                        TPtiKeyboardType& aQwertyKbType );
 
         /**
          * Returns the pool Id for a key
@@ -125,9 +128,10 @@
 
         /**
-         * Select keyboard types according to available physical keyboard(s)
+         * Get physical Itu-T and QWERTY keyboard types of the device
          */